@@ -7,7 +7,7 @@
 ##' @param masterstack rasterStack containing all monthly precipitation, 
 ##' min temperature, max temperature, and optionally mean temperature rasters.
 ##'
-##' @param solradstack rasterStack of monthly solar radiation
+##' @param solradstack rasterStack of monthly solar radiation, can be \code{NULL} if not needed.
 ##'
 ##' @param var vector of names of variables to generate, see Details.
 ##'
@@ -39,6 +39,8 @@
 ##' growingDegDays5 \cr
 ##' maxTempColdest \cr
 ##' minTempWarmest \cr
+##' meanTempColdest \cr
+##' meanTempWarmest \cr
 ##' monthCountByTemp10 \cr
 ##' PETColdestQuarter \cr
 ##' PETDriestQuarter \cr
@@ -84,9 +86,9 @@
 # Function takes stack of precip, mintemp, maxtemp, bioclim, and a stack of solar radiation, and generates rasterstack of new variables
 # var is a vector of variable names that will be generated. 
 
-layerCreation <- function(masterstack, solradstack, var, tempScale = 1, precipScale = 1) {
+layerCreation <- function(masterstack, solradstack = NULL, var, tempScale = 1, precipScale = 1) {
 
-	allvar <- c("annualPET", "aridityIndexThornthwaite", "climaticMoistureIndex", "continentality", "embergerQ", "growingDegDays0", "growingDegDays5", "maxTempColdest", "minTempWarmest", "monthCountByTemp10", "PETColdestQuarter", "PETDriestQuarter", "PETseasonality", "PETWarmestQuarter", "PETWettestQuarter", "thermicityIndex")
+	allvar <- c("annualPET", "aridityIndexThornthwaite", "climaticMoistureIndex", "continentality", "embergerQ", "growingDegDays0", "growingDegDays5", "maxTempColdest", "minTempWarmest", "meanTempColdest", "meanTempWarmest", "monthCountByTemp10", "PETColdestQuarter", "PETDriestQuarter", "PETseasonality", "PETWarmestQuarter", "PETWettestQuarter", "thermicityIndex")
 
 	if (class(var) == 'character') {
 		if (length(var) == 1) {
@@ -106,11 +108,19 @@ layerCreation <- function(masterstack, solradstack, var, tempScale = 1, precipSc
 		stop('\nVariable names must match official set.')
 	}
 	
+	solradVar <- c('annualPET','PETseasonality','aridityIndexThornthwaite','climaticMoistureIndex','PETColdestQuarter','PETWarmestQuarter','PETWettestQuarter','PETDriestQuarter')
+	needsSolRad <- ifelse(any(var %in% solradVar), TRUE, FALSE)
+	
 	#naming checks and name standardization
-	check <- verifyRasterNames(masterstack, solradstack, returnRasters = TRUE)
-	solradstack <- check[[grep(paste0(.var$solrad, '\\d\\d?', .var$solrad_post), names(check))]]
-	masterstack <- raster::dropLayer(check, names(solradstack))
-		
+	if (needsSolRad) {
+		check <- verifyRasterNames(masterstack, solradstack, returnRasters = TRUE)
+		solradstack <- check[[grep(paste0(.var$solrad, '\\d\\d?', .var$solrad_post), names(check))]]
+		masterstack <- raster::dropLayer(check, names(solradstack))
+	} else {
+		check <- verifyRasterNames(masterstack, returnRasters = TRUE)
+		masterstack <- check	
+	}	
+	
 	#receiving list
 	reslist <- vector('list', length = length(var))
 	names(reslist) <- var
@@ -125,7 +135,10 @@ layerCreation <- function(masterstack, solradstack, var, tempScale = 1, precipSc
 	tminstack <- tminstack[[order(as.numeric(gsub(paste0(.var$tmin, '([0-9]+)', .var$tmin_post), "\\1", names(tminstack))))]]
 	tmaxstack <- tmaxstack[[order(as.numeric(gsub(paste0(.var$tmax, '([0-9]+)', .var$tmax_post), "\\1", names(tmaxstack))))]]
 	precipstack <- precipstack[[order(as.numeric(gsub(paste0(.var$precip, '([0-9]+)', .var$precip_post), "\\1", names(precipstack))))]]
-	solradstack <- solradstack[[order(as.numeric(gsub(paste0(.var$solrad, '([0-9]+)', .var$solrad_post), "\\1", names(solradstack))))]]
+	
+	if (needsSolRad) {
+		solradstack <- solradstack[[order(as.numeric(gsub(paste0(.var$solrad, '([0-9]+)', .var$solrad_post), "\\1", names(solradstack))))]]
+	}
 	
 	# adjust temperature rasters to degrees C
 	if (tempScale != 1) {
@@ -168,10 +181,10 @@ layerCreation <- function(masterstack, solradstack, var, tempScale = 1, precipSc
 		bioclimstack[['bio12']] <- raster::calc(precipstack, fun = sum)
 	}
 	if (any(c('thermicityIndex', 'embergerQ', 'climaticMoistureIndex') %in% var)) {
-		bioclimstack <- raster::stack(bioclimstack)
+		bioclimstack <- raster::stack(bioclimstack[!sapply(bioclimstack, is.null)])
 	}
 				
-	if (any(c('minTempWarmest','maxTempColdest','thermicityIndex','continentality') %in% var)) {
+	if (any(c('minTempWarmest', 'maxTempColdest', 'meanTempWarmest', 'meanTempColdest', 'thermicityIndex', 'continentality') %in% var)) {
 		message('\t\t...temp extremes...')
 		tempExtremes <- otherTempExtremes(tmeanstack, tminstack, tmaxstack)
 		if ('minTempWarmest' %in% var) {
@@ -180,6 +193,12 @@ layerCreation <- function(masterstack, solradstack, var, tempScale = 1, precipSc
 		if ('maxTempColdest' %in% var) {
 			reslist[['maxTempColdest']] <- tempExtremes[['maxTempColdest']]
 		}
+		if ('meanTempWarmest' %in% var) {
+			reslist[['meanTempWarmest']] <- tempExtremes[['meanTempWarmest']]
+		}
+		if ('meanTempColdest' %in% var) {
+			reslist[['meanTempColdest']] <- tempExtremes[['meanTempColdest']]
+		}
 	}
 
 	#growing degree days with temp base of 5 deg C and 0 deg C
@@ -224,7 +243,7 @@ layerCreation <- function(masterstack, solradstack, var, tempScale = 1, precipSc
 	}
 
 	#annual potential evapotranspiration
-	if (any(c('annualPET','PETseasonality','aridityIndexThornthwaite','climaticMoistureIndex','PETColdestQuarter','PETWarmestQuarter','PETWettestQuarter','PETDriestQuarter') %in% var)) {
+	if (any(solradVar %in% var)) {
 		monthPET <- monthlyPET(Tmean = tmeanstack, RA = solradstack, TD = abs(tmaxstack - tminstack))
 	}
 
@@ -273,8 +292,8 @@ layerCreation <- function(masterstack, solradstack, var, tempScale = 1, precipSc
 		reslist[['aridityIndexThornthwaite']] <- aridIndThorn
 	}
 
-	# if minTempWarmest or maxTempColdest were requested, put them back on the same
-	# scale as the input temperature rasters
+	# if minTempWarmest, maxTempColdest, meanTempWarmest, meanTempColdest were requested, 
+	# put them back on the same scale as the input temperature rasters
 	if ('minTempWarmest' %in% var) {
 		reslist[['minTempWarmest']] <- reslist[['minTempWarmest']] * tempScale
 	}
@@ -283,6 +302,13 @@ layerCreation <- function(masterstack, solradstack, var, tempScale = 1, precipSc
 		reslist[['maxTempColdest']] <- reslist[['maxTempColdest']] * tempScale
 	}
 
+	if ('meanTempWarmest' %in% var) {
+		reslist[['meanTempWarmest']] <- reslist[['meanTempWarmest']] * tempScale
+	}
+
+	if ('meanTempColdest' %in% var) {
+		reslist[['meanTempColdest']] <- reslist[['meanTempColdest']] * tempScale
+	}
 
 	reslist <- raster::stack(reslist)
 	return(reslist)
